@@ -45,7 +45,7 @@ use base qw( Log::Fine::Handle );
 
 use File::Basename;
 use Log::Fine;
-use Sys::Syslog qw( :standard :macros );
+use Sys::Syslog 0.13 qw( :standard :macros );
 
 # Constant: LOG_MAPPING
 #
@@ -62,7 +62,21 @@ use constant LOG_MAPPING => {
                               7 => LOG_DEBUG,
 };
 
-# Constant: DEFAULT_LOG_IDENT
+# Private Methods
+# --------------------------------------------------------------------
+
+{
+        my $flag = 0;
+
+        # Getter/Setter for flag
+        sub _flag
+        {
+                $flag = 1 if (defined $_[0] and $_[0] =~ /\d/ and $_[0] > 0);
+                return $flag;
+        }
+}
+
+# --------------------------------------------------------------------
 
 =head1 METHODS
 
@@ -105,6 +119,11 @@ sub _init
         # call the super object
         $self->SUPER::_init();
 
+        # Make sure we have one and only one syslog object defined
+        $self->_fatal(
+                      sprintf("One and _only_ one %s object may be defined",
+                              ref $self)) if _flag();
+
         # set ident
         $self->{ident} = basename $0;
 
@@ -114,11 +133,12 @@ sub _init
 
         # set the default facility
         $self->{facility} = LOG_LOCAL0
-            unless (defined $self->{faciity}
+            unless (defined $self->{facility}
                     and $self->{facility} =~ /\w+/);
 
-        # open the syslog connection
+        # open the syslog connection and set flag
         openlog($self->{ident}, $self->{logopts}, $self->{facility});
+        _flag(1);
 
         # Victory!
         return $self;
@@ -176,7 +196,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: Syslog.pm 200 2010-01-03 20:20:44Z cfuhrman $
+  $Id: 702363086ed67656b75b353e081284433cb242cf $
 
 =head1 COPYRIGHT & LICENSE
 
